@@ -186,21 +186,21 @@ class Registro(RegistroBase):
             paymentrequest_0_itemamt=self.formatador.formata_decimal(self.pedido.valor_subtotal),
             paymentrequest_0_invnum=self.pedido.numero,
 
-            paymentrequest_0_shiptoname=self.pedido.endereco_entrega.nome,
-            paymentrequest_0_shiptostreet="{}, {} {}".format(self.pedido.endereco_entrega.endereco, self.pedido.endereco_entrega.numero, self.pedido.endereco_entrega.complemento),
-            paymentrequest_0_shiptostreet2=self.pedido.endereco_entrega.bairro,
-            paymentrequest_0_shiptocity=self.pedido.endereco_entrega.cidade,
+            paymentrequest_0_shiptoname=unicode(self.pedido.endereco_entrega.nome),
+            paymentrequest_0_shiptostreet=u"{}, {} {}".format(self.pedido.endereco_entrega.endereco, self.pedido.endereco_entrega.numero, self.pedido.endereco_entrega.complemento),
+            paymentrequest_0_shiptostreet2=unicode(self.pedido.endereco_entrega.bairro),
+            paymentrequest_0_shiptocity=unicode(self.pedido.endereco_entrega.cidade),
             paymentrequest_0_shiptostate=self.pedido.endereco_entrega.estado,
             paymentrequest_0_shiptozip=self.pedido.endereco_entrega.cep,
             paymentrequest_0_shiptocountrycode="BR",
             paymentrequest_0_shiptophonenum=self.pedido.cliente.telefone_principal
         )
         for indice, item in enumerate(self.pedido.itens.all()):
-            self.define_valor_de_atributo_de_item(request_payment, "NAME", indice, item.nome[:127])
-            self.define_valor_de_atributo_de_item(request_payment, "DESC", indice, item.produto.descricao_completa[:127])
+            self.define_valor_de_atributo_de_item(request_payment, "NAME", indice, unicode(item.nome[:127]))
+            self.define_valor_de_atributo_de_item(request_payment, "DESC", indice, unicode(item.produto.descricao_completa[:127]))
             self.define_valor_de_atributo_de_item(request_payment, "AMT", indice, self.formatador.formata_decimal(item.preco_venda))
             self.define_valor_de_atributo_de_item(request_payment, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
-            self.define_valor_de_atributo_de_item(request_payment, "NUMBER", indice, item.sku[:127])
+            self.define_valor_de_atributo_de_item(request_payment, "NUMBER", indice, unicode(item.sku[:127]))
             self.define_valor_de_atributo_de_item(request_payment, "ITEMURL", indice, item.produto.get_absolute_url())
 
         return request_payment.to_dict()
